@@ -2,7 +2,7 @@ import sys
 
 from PyQt5.QtWidgets import QApplication
 
-from mneprepV2.prep_classes.main_window import MainWindow
+from mneprep.prep_classes.main_window import MainWindow
 
 if __name__ == '__main__':
     app = QApplication(sys.argv)
